psychopy_ext.ui.Choices — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.ui.Choices

class `psychopy_ext.ui.` `Choices`(module, name='', alias=None, order=None)

  Holds choices for calling experiments.

    Args: | module (str or module) The module you want to call. If your script is in ‘scripts/main.py’, then module should be ‘scripts.main’. You can also give the module itself if you already have it imported:
        import scripts.main
        exp_choices = Choices(scripts.main)
  Kwargs: | name (str, default: ‘’) Name of the experiment. alias (str, default: None) For CLI: alias for calling this experiment. If None, will be inferred from `module`. order (list, default: None) For GUI: Order of tabs (classes).

  `__init__`(module, name='', alias=None, order=None)

    Holds choices for calling experiments.

      Args: | module (str or module) The module you want to call. If your script is in ‘scripts/main.py’, then module should be ‘scripts.main’. You can also give the module itself if you already have it imported:
          import scripts.main
          exp_choices = Choices(scripts.main)
    Kwargs: | name (str, default: ‘’) Name of the experiment. alias (str, default: None) For CLI: alias for calling this experiment. If None, will be inferred from `module`. order (list, default: None) For GUI: Order of tabs (classes).

  Methods

  `__init__`(module[, name, alias, order]) | Holds choices for calling experiments.